@@ -103,14 +103,13 @@
 #' These models are univariate. No xregs are used in the modeling process.
 #'
 #'
-#' @seealso [fit.model_spec()], [set_engine()]
+#' @seealso `fit.model_spec()`, `set_engine()`
 #'
 #' @examples
 #' library(dplyr)
 #' library(parsnip)
 #' library(rsample)
 #' library(timetk)
-#' library(modeltime)
 #'
 #' # Data
 #' m750 <- m4_monthly %>% filter(id == "M750")
@@ -345,18 +344,23 @@ window_function_fit_impl <- function(x, y, id = NULL,
 
     if (is_grouped) {
         window_model <- constructed_tbl %>%
-            dplyr::group_by(!! rlang::sym(id))
+            dplyr::group_by(!!rlang::sym(id))
     } else {
         window_model <- constructed_tbl
     }
 
     window_model <- window_model %>%
-        dplyr::arrange(dplyr::all_of(idx_col)) %>%
-        dplyr::slice_tail(n = period) %>%
-        dplyr::summarise(
-            dplyr::across(value, .fns = window_function, ...),
-            .groups = "drop") %>%
-        dplyr::ungroup()
+        dplyr::arrange(dplyr::pick(dplyr::all_of(idx_col))) %>%
+        dplyr::slice_tail(n = period)
+
+    window_function <- rlang::as_function(window_function)
+
+
+    window_model <-
+        dplyr::reframe(
+            window_model,
+            dplyr::across(value, .fns = function(.x) window_function(.x, ...)),
+            )
 
     # return(window_model)
 
@@ -506,7 +510,7 @@ predict.window_function_fit_impl <- function(object, new_data, ...) {
 #
 #     # APPLY WINDOW
 #     window_df <- window_df %>%
-#         dplyr::arrange(dplyr::all_of(idx_col)) %>%
+#         dplyr::arrange(dplyr::pick(dplyr::all_of(idx_col))) %>%
 #         dplyr::slice_tail(n = period) %>%
 #         dplyr::ungroup()
 #
